#
# spec file for package preload
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           preload
Version:        1.2
Release:        6.7.12
Summary:        Preloads Files into System Cache for Faster Booting
License:        GPLv2+
Group:          System/Boot
# svn export https://svn.suse.de/svn/desktop/trunk/preload
Source0:        preload.tar.bz2
Source1:        %name-rpmlintrc
Source2:        preamble
Source6:        bootfaster.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  e2fsprogs-devel gcc-c++ update-desktop-files
PreReq:         %fillup_prereq %insserv_prereq
# for the kmp
BuildRequires:  kernel-source kernel-syms module-init-tools systemtap
BuildRequires:  kernel-default kernel-default-base-debuginfo kernel-default-debuginfo kernel-default-devel-debuginfo
BuildRequires:  kernel-desktop kernel-desktop-base-debuginfo kernel-desktop-debuginfo kernel-desktop-devel-debuginfo
ExclusiveArch:  %ix86 x86_64
Recommends:     preload-kmp systemtap-runtime
%suse_kernel_module_package -p %_sourcedir/preamble  kdump um debug trace xen vim pae

%description
Preload lists files to load into the system cache. This shortens system
boot time if used correctly.

%package KMP
License:        GPLv2+
Summary:        Preload Kernel Module
Group:          System/Boot

%description KMP
This will work with preload hand in hand to make sure no unnecessary
files are preload.

%prep
%setup -n preload
mkdir obj

%build
# ugly work around for bnc#588293
unset MALLOC_PERTURB_
make "CFLAGS=$RPM_OPT_FLAGS"
for flavor in %flavors_to_build; do
    rm -rf obj/$flavor
    rm -rf source
    mkdir source
    cp stap/preloadtrace.stp stap/Kbuild source
    touch source/preloadtrace.c
    kernels=`cd /usr/lib/debug/lib/modules && ls -1d *-$flavor `
    cp -r source obj/$flavor
    make -C /usr/src/linux-obj/%_target_cpu/$flavor modules M=$PWD/obj/$flavor 
    stap -p 4 -DMAXSTRINGSIZE=300 -DMAXSKIPPED=2000 -DSTAP_NEED_GETTIMEOFDAY=1 -r $kernels -m preloadtrace  obj/$flavor/preloadtrace.stp
    mv preloadtrace.ko obj/$flavor 
done

%install
mkdir -p $RPM_BUILD_ROOT/usr/bin
mkdir -p $RPM_BUILD_ROOT/sbin
mkdir -p $RPM_BUILD_ROOT/usr/bin
mkdir -p $RPM_BUILD_ROOT/usr/sbin
mkdir -p $RPM_BUILD_ROOT/etc/init.d
#mkdir -p $RPM_BUILD_ROOT/etc/cron.daily
install -m 755 preload $RPM_BUILD_ROOT/sbin
install -m 755 preload-client $RPM_BUILD_ROOT/sbin
install -m 755 print-bmap $RPM_BUILD_ROOT/sbin
#install -m 755 update_preload $RPM_BUILD_ROOT/usr/bin
#install -m 755 bootcache $RPM_BUILD_ROOT/usr/sbin
install -m 755 prepare_preload $RPM_BUILD_ROOT/usr/bin
install -m 755 init.earlyxdm $RPM_BUILD_ROOT/etc/init.d/earlyxdm
install -m 755 init.startpreload $RPM_BUILD_ROOT/etc/init.d/boot.startpreload
install -m 755 init.stoppreload $RPM_BUILD_ROOT/etc/init.d/stoppreload
install -m 755 stop_preload $RPM_BUILD_ROOT/usr/sbin
install -m 755 waitforidle $RPM_BUILD_ROOT/usr/bin/waitforidle
#install -m 755 cron $RPM_BUILD_ROOT/etc/cron.daily/suse.de-update-preload
# empty dir
mkdir -p $RPM_BUILD_ROOT/var/cache/preload
#mkdir -p $RPM_BUILD_ROOT/opt/kde3/share/autostart
#install -m 644 appspreload.desktop $RPM_BUILD_ROOT/opt/kde3/share/autostart
#install -m 755 appspreloader.sh $RPM_BUILD_ROOT/usr/bin
##suse_update_desktop_file -n $RPM_BUILD_ROOT/opt/kde3/share/autostart/appspreload.desktop
cp %{S:6} .
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=systemtap
for flavor in %flavors_to_build; do
    make -C /usr/src/linux-obj/%_target_cpu/$flavor modules_install \
	 M=$PWD/obj/$flavor
done

%post
%{fillup_and_insserv -ny preload earlyxdm}
%{fillup_and_insserv -nY preload boot.startpreload}
%{fillup_and_insserv -nY preload stoppreload}

%postun
%{insserv_cleanup}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-, root, root)
%doc bootfaster.diff
/sbin/*
/usr/sbin/*
/usr/bin/*
#/etc/cron.daily/suse.de-update-preload
/etc/init.d/*
/var/cache/preload
#/opt/kde3

%changelog
* Mon Jan 24 2011 gregkh@suse.de
- fix preload kmp build error with newer systemtap and kernel.
  Thanks to Kshitij Kulshreshtha <kkhere.geo@gmail.com> for the fix.
* Fri Oct 29 2010 coolo@novell.com
- work on perl warnings and remove -s 3 from stap, it's buggy atm
* Tue Jun 29 2010 coolo@novell.com
- remove more warnings
* Thu May 13 2010 coolo@novell.com
- do not require the rebuild counter of the kernel
* Mon Mar 22 2010 coolo@novell.com
- disable preload if /usr is on an extra partition
* Mon Mar 22 2010 coolo@novell.com
- mls does not like the supplements and they are
  not necessary (bnc#589431)
* Mon Mar 15 2010 coolo@novell.com
- sys.mmap does no longer work on i586, so use new 2.6.33 function
* Mon Mar 15 2010 coolo@novell.com
- fix build in adding work around for bnc#588293
* Mon Jan 25 2010 coolo@novell.com
- remove waitfornm (bnc#556883)
* Wed Nov  4 2009 coolo@novell.com
- ignore negative PIDs - gives very prominently
  errors in console (bnc#551635)
* Mon Nov  2 2009 coolo@novell.com
- fix the logic in the worker thread (bnc#551801)
* Thu Oct 15 2009 coolo@novell.com
- print less warnings by default (bnc#546359)
* Wed Oct  7 2009 coolo@novell.com
- fixes by Michael Matz to make it more robust (bnc#542538)
* Mon Sep 28 2009 coolo@novell.com
- do not require but recommend working kmp (bnc#530655)
* Fri Sep 18 2009 coolo@novell.com
- fix for bnc#539976
* Wed Sep 16 2009 coolo@novell.com
- fix typo in rsyslog check
* Tue Sep 15 2009 coolo@novell.com
- do not start login manager before remote users are available (fate#301200)
* Thu Aug 20 2009 coolo@novell.com
- do not check the config file for rsyslog (bnc#530569)
* Tue Aug 18 2009 coolo@novell.com
  version 1.1
- simplify the stap format
- remove bootcache code completely
- rework process tree parsing to catch all IO
* Sun Aug  9 2009 coolo@novell.com
- kernel-extra is no more
* Sun Aug  2 2009 coolo@novell.com
- kernel debuginfo is split
- leave out pae module as it's no longer used by default
* Wed Jul 22 2009 coolo@novell.com
- new desktop flavor
* Mon Jul 13 2009 coolo@novell.com
- require systemtap-runtime instead of recommending (bnc#521357)
* Mon Jul 13 2009 coolo@novell.com
- disable bootcache for now
- make killall -q (bnc#494082)
* Tue Jun  9 2009 coolo@suse.de
- pae should work again
* Tue May 26 2009 coolo@suse.de
- hopefully fix the handling of reads on pipes
* Mon May 25 2009 coolo@suse.de
- ignore pae too for now
* Sat May 23 2009 coolo@suse.de
- ignore legacy as its debuginfos conflict with default
* Wed May 20 2009 coolo@novell.com
- recommend systemtap-runtime, that's enough
- kernel-pae is no more
* Wed May  6 2009 coolo@suse.de
- if the output goes to serial console, give some more buffer
* Mon May  4 2009 coolo@suse.de
- don't be too verbose (bnc#494082)
* Thu Apr 16 2009 coolo@suse.de
- don't require the kmp, it still has a function without regenerating
- removed debug output from waitforidle
* Wed Apr  8 2009 coolo@suse.de
- [stp] don't show openat for ignored fds
- [stp] increase buffer size
* Tue Apr  7 2009 coolo@suse.de
- don't fail when there is not enough space to reorder
- fix dos line feeds in input
* Mon Apr  6 2009 coolo@suse.de
- make automatically use of bootcache (*EXPERIMENTAL*):
  relink files into /appcache/boot, so they are in order of
  booting. The logic behind it needs to be improved, currently
  it's done on every boot
- let the kernel command line say where to save the preload trace.
  This allows preloadlog=/dev/zero (interesting for booting live cd) or
  preloadlog=/dev/ttyS0 (interesting for profiling live cd)
* Thu Apr  2 2009 coolo@suse.de
- ok, I give up. install all kernels
* Thu Apr  2 2009 coolo@suse.de
- leave out the rebuild counter in the kernel version require
* Tue Mar 31 2009 coolo@suse.de
- staprun needs the kmp exactly in kernel-version's path not in
  weak-updates, so we need to make this require explicit
* Wed Mar 25 2009 coolo@suse.de
- several fixes
- removed remap support - not everyone has its root on sda6 :)
* Wed Feb 25 2009 coolo@suse.de
- preload requires stapio
* Thu Feb 12 2009 coolo@suse.de
- majorly reworked how preload works. Experimental for now
* Wed Oct 22 2008 coolo@suse.de
- fix syntax (bnc#435512)
* Sat Aug 23 2008 aj@suse.de
- Fix init scripts.
- Fix fillup call.
* Tue Aug 12 2008 coolo@suse.de
- now fixing differently for different checks ;(
* Mon Aug 11 2008 coolo@suse.de
- fix rpmlint warnings about init scripts
* Mon May 12 2008 coolo@suse.de
- update the preload lists (bnc#375313)
* Wed Nov  7 2007 coolo@suse.de
- fix nfs mount catch (#333688)
* Fri Nov  2 2007 coolo@suse.de
- adding correct Prereqs
* Fri Sep 21 2007 coolo@suse.de
- removing temporary files from file lists (#309149)
* Tue Sep 11 2007 coolo@suse.de
- make earlyxdm depend on haldaemon, so that we don't get a race condition.
  It's far from optimal (#309171)
* Mon Sep  3 2007 coolo@suse.de
- update preload lists for cursor change (uncommited changes)
- revert the workaround for #302010 now that we have a fix
* Thu Aug 30 2007 aj@suse.de
- Fix waitfornm typo (#305757).
* Sun Aug 26 2007 jblunck@suse.de
- Remove blktrace since this is in a separate package now
* Tue Aug 21 2007 ro@suse.de
- fix typo
* Tue Aug 21 2007 dmueller@suse.de
- readd kbd dependency as a kludge for (#302010)
* Wed Jul  4 2007 coolo@suse.de
- adding experimental support for ext2remapper
* Thu Jun 21 2007 coolo@suse.de
- remove kbd check - it's from the old earlykdm
* Wed Jun 20 2007 coolo@suse.de
- harmonize earlykdm and earlygdm into earlyxdm
* Mon Jun 18 2007 coolo@suse.de
- remove the boot scripts
* Sat Jun 16 2007 coolo@suse.de
- reduce some files
* Thu Jun 14 2007 coolo@suse.de
- update gdm file too
* Fri Apr 20 2007 matz@suse.de
- Fix off-by-one (#260836).
* Fri Apr 20 2007 coolo@suse.de
- update from SVN with updated file lists (#237120)
* Sat Nov 25 2006 olh@suse.de
- boot.preload has no hard requirement for boot.klog
  change insserv dependencies from Required-start to Should-start
  scripts will still get the right ordering that way without
  triggering insserv and rpm post errors.
* Mon Mar 20 2006 matz@suse.de
- Handle fifo gracefully.  (#158734)
- Integrate preload-gnome-session-files.diff into tarball.
* Thu Mar 16 2006 federico@novell.com
- Updated preload-gnome-session-files.diff to preload all the files which
  a GNOME session opens during login.
* Sat Mar 11 2006 federico@novell.com
- Added preload-gnome-session-files.diff with a bunch of files needed
  for a GNOME session.  This reduces cold login time from about 30
  sec. to about 12 sec.
* Thu Feb  9 2006 matz@suse.de
- Accept a cache file, update it via cron.daily if necessary.
* Thu Feb  9 2006 coolo@suse.de
- don't hang on boot in opening stale unix domain sockets
* Tue Feb  7 2006 ro@suse.de
- fix typo in boot.preload (klogd vs klog)
* Tue Feb  7 2006 coolo@suse.de
- avoid loop between boot.localfs and boot.preload_early
* Mon Feb  6 2006 coolo@suse.de
- streamline patches with SVN
- do not wait for update_preload (#117023)
* Thu Feb  2 2006 rodrigo@suse.de
- Added preload-gdm.patch to preload some basic GNOME processes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 aj@suse.de
- boot.coldplug does not exist anymore (#144652).
* Thu Nov 10 2005 rml@suse.de
- Newest SVN snapshot, with gdm config
* Thu Nov 10 2005 coolo@suse.de
- adoption to new fontconfig file names
* Thu Aug 25 2005 matz@suse.de
- Don't be verbose anymore.
* Tue Aug 23 2005 coolo@suse.de
- new lists
* Mon Aug 22 2005 coolo@suse.de
- reworked majorly
* Wed Jan 26 2005 coolo@suse.de
- clean out the lists a bit
* Mon Jan 10 2005 coolo@suse.de
- initial package
